@@ -1,7 +1,8 @@
 from .detect import Model
+from .tracker import Tracker
 from .faces import FaceRecognizer, FaceAttribute
 from .plates import PlateDetector, PlateRecognizer
 from .ocr import TextSystem
     
 
-__all__ = [Model, FaceRecognizer, FaceAttribute, PlateDetector, PlateRecognizer, TextSystem]
+__all__ = [Model, Tracker, FaceRecognizer, FaceAttribute, PlateDetector, PlateRecognizer, TextSystem]
