@@ -1,7 +1,7 @@
 
 from ..client import Abraia
-from ..utils import get_color, url_path, make_dirs
-from . import classify, detect 
+from ..utils import url_path, make_dirs
+from . import classify, detect
 
 import os
 import shutil
@@ -14,14 +14,14 @@ from sklearn.model_selection import train_test_split
 abraia = Abraia()
 
 
-def load_projects():
+def list_datasets():
     folders = abraia.list_files()[1]
     return [folder['name'] for folder in folders if abraia.check_file(f"{folder['name']}/annotations.json")]
 
 
-def load_dataset(project):
+def list_images(project):
     files = abraia.list_files(f"{project}/")[0]
-    dataset = [f for f in files if f['type'].startswith('image/')]
+    dataset = [f for f in files if f['type'] in ['image/jpeg', 'image/png']]
     for data in dataset:
         data['url'] = url_path(f"{abraia.userid}/{data['path']}")
     return dataset
@@ -145,14 +145,16 @@ def save_config(dataset, classes):
 
 
 def split_dataset(annotations):
+    # TODO: Split dataset by classes to avoid class imbalance
+    backgrounds = [annotation for annotation in annotations if not annotation.get('objects')]
+    annotations = [annotation for annotation in annotations if annotation.get('objects')]
     train, test = train_test_split(annotations, test_size=0.3)
     val, test = train_test_split(test, test_size=0.5)
+    train.extend(backgrounds)
     return train, val, test
 
 
 def create_dataset(dataset, task, classes):
-    #shutil.rmtree(f"{dataset}/")
-    # TODO: If folder exists skip or recreate based on cached files?
     if not os.path.exists(dataset):
         annotations = load_annotations(dataset)
         train, val, test = split_dataset(annotations)
